==> openerp-server_5.0.6.orig.tar.gz: openerp-server-5.0.6/bin/addons/crm_profiling/__terp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'crm_profiling management',
    'version': '1.3',
    'category': 'Generic Modules/CRM & SRM',
    'description': """
    This module allow users to perform segmentation within partners.
    It use the profiles criteria from the earlier segmentation module and improve it thanks to the new concept of questionnaire. You can now regroup questions into a questionnaire and directly use it on a partner.

    It also has been merged with the earlier CRM & SRM segmentation tool because they were overlapping.


    The menu items related are in "CRM & SRM\Configuration\Segmentations"


    * Note: this module is not compatible with the module segmentation, since it's the same which has been renamed.
    """,
    'author': 'Tiny',
    'website': 'http://www.openerp.com',
    'depends': ['base', 'crm'],
    'init_xml': [],
    'update_xml': ['security/ir.model.access.csv', 'crm_profiling_view.xml'],
    'demo_xml': ['crm_profiling_demo.xml'],
    'installable': True,
    'active': False,
    'certificate': '0033984979005',
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> openerp-server_5.0.15.orig.tar.gz: openerp-server-5.0.15/bin/addons/crm_profiling/__terp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'crm_profiling management',
    'version': '1.3',
    'category': 'Generic Modules/CRM & SRM',
    'description': """
    This module allows users to perform segmentation within partners.
    It uses the profiles criteria from the earlier segmentation module and improve it. Thanks to the new concept of questionnaire. You can now regroup questions into a questionnaire and directly use it on a partner.

    It also has been merged with the earlier CRM & SRM segmentation tool because they were overlapping.

    The menu items related are in "CRM & SRM\Configuration\Segmentations"


    * Note: this module is not compatible with the module segmentation, since it's the same which has been renamed.
    """,
    'author': 'Tiny',
    'website': 'http://www.openerp.com',
    'depends': ['base', 'crm'],
    'init_xml': [],
    'update_xml': ['security/ir.model.access.csv', 'crm_profiling_view.xml'],
    'demo_xml': ['crm_profiling_demo.xml'],
    'installable': True,
    'active': False,
    'certificate': '0033984979005',
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
